@@ -1,6 +1,6 @@
 /*
     YAGF - cuneiform and tesseract OCR graphical front-ends
-    Copyright (C) 2009-2013 Andrei Borovsky <anb@symmetrica.net>
+    Copyright (C) 2009-2012 Andrei Borovsky <anb@symmetrica.net>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ class QImage;
 class RotationCropper
 {
 public:
-    RotationCropper(QImage * image, QRgb color, int dtr);
+    RotationCropper(QImage * image, QRgb color);
     ~RotationCropper();
     QRect crop();
 private:
@@ -47,7 +47,6 @@ private:
     int maxval;
     //int clAltCount;
     int whitesCount;
-    int darktr;
     int whitetr;
     int whiteAlt;
 
