@@ -21,8 +21,15 @@
 #include <QLocale>
 #include <stdio.h>
 #include <QLibraryInfo>
+#include <QProcessEnvironment>
 #include "mainform.h"
 #include "settings.h"
+#include "langselectdialog.h"
+
+//#define MEM_DEBUG
+#ifdef MEM_DEBUG
+#include <mcheck.h>
+#endif
 
 void parseCmdLine(const QStringList &args)
 {
@@ -47,6 +54,10 @@ void parseCmdLine(const QStringList &args)
 
 int main(int argc, char *argv[])
 {
+#ifdef MEM_DEBUG
+mtrace();
+#endif
+
     QApplication app(argc, argv);
     parseCmdLine(app.arguments());
     Settings * settings = Settings::instance();
@@ -59,8 +70,9 @@ int main(int argc, char *argv[])
     if (!settings->useNoLocale()) {
         translator.load(qmName, QString(QML_INSTALL_PATH));
         app.installTranslator(&translator);
-        settings->makeLanguageMaps();
+
     }
+    settings->makeLanguageMaps();
     QTranslator translator2;
     if (settings->useRussianLocale())
         translator2.load("qt_ru_RU", QLibraryInfo::location(QLibraryInfo::TranslationsPath));
@@ -68,7 +80,15 @@ int main(int argc, char *argv[])
         translator2.load("qt_" + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
     if (!settings->useNoLocale())
         app.installTranslator(&translator2);
+    if (settings->getSelectedLanguages().count() == 0) {
+        //LangSelectDialog lsd;
+        //lsd.exec();
+    }
     MainForm window;
     window.show();
-    return app.exec();
+    int res = app.exec();
+#ifdef MEM_DEBUG
+muntrace();
+#endif
+    return res;
 }
