@@ -24,12 +24,13 @@
 #include "pdf2ppt.h"
 #include "ghostscr.h"
 #include "configdialog.h"
-#include "advancedconfigdialog.h"
 #include "mainform.h"
 #include "tpagecollection.h"
 #include "scanner.h"
 #include "projectmanager.h"
-#include "forcelocaledialog.h"
+#include "langselectdialog.h"
+#include "tiffimporter.h"
+#include "busyform.h"
 #include <signal.h>
 #include <QComboBox>
 #include <QLabel>
@@ -57,6 +58,7 @@
 #include <QClipboard>
 #include <QMap>
 #include <QWidgetAction>
+#include <QPushButton>
 #include "qgraphicsinput.h"
 #include "utils.h"
 #include "qxtunixsignalcatcher.h"
@@ -95,7 +97,7 @@ MainForm::MainForm(QWidget *parent): QMainWindow(parent)
     graphicsInput->addToolBarAction(actionRotate_90_CCW);
     graphicsInput->addToolBarAction(actionRotate_180);
     graphicsInput->addToolBarAction(actionRotate_90_CW);
-    graphicsInput->addToolBarAction(actionPrepare_Page);
+    //graphicsInput->addToolBarAction(actionPrepare_Page);
     graphicsInput->addToolBarAction(actionDeskew);
     graphicsInput->addToolBarSeparator();
     graphicsInput->addToolBarAction(actionSelect_Text_Area);
@@ -103,6 +105,7 @@ MainForm::MainForm(QWidget *parent): QMainWindow(parent)
     graphicsInput->addToolBarAction(ActionClearAllBlocks);
 
     label->setListWidget(sideBar);
+    pdfx = NULL;
 
     connect(sideBar, SIGNAL(pageSelected(int)), pages, SLOT(pageSelected(int)));
     connect(label, SIGNAL(pageRemoved(int)), pages, SLOT(pageRemoved(int)));
@@ -125,6 +128,7 @@ MainForm::MainForm(QWidget *parent): QMainWindow(parent)
     connect(actionAbout, SIGNAL(triggered()), this, SLOT(showAboutDlg()));
     connect(actionOnlineHelp, SIGNAL(triggered()), this, SLOT(showHelp()));
     connect(actionCopyToClipboard, SIGNAL(triggered()),textEdit, SLOT(copyClipboard()));
+    connect(actionSelect_All_Text, SIGNAL(triggered()),textEdit, SLOT(selectAll()));
     connect(graphicsInput, SIGNAL(rightMouseClicked(int, int, bool)), this, SLOT(rightMouseClicked(int, int, bool)));
     connect(actionSelect_HTML_format, SIGNAL(triggered()), this, SLOT(selectHTMLformat()));
 
@@ -136,10 +140,11 @@ MainForm::MainForm(QWidget *parent): QMainWindow(parent)
     connect(graphicsInput, SIGNAL(deleteBlock(QRect)), pages, SLOT(deleteBlock(QRect)));
     connect(sideBar, SIGNAL(fileRemoved(int)), pages, SLOT(pageRemoved(int)));
     connect (pages, SIGNAL(addSnippet(int)), this, SLOT(addSnippet(int)));
+    connect(actionSelect_languages, SIGNAL(triggered()), this, SLOT(selectLanguages()));
 
     selectLangsBox = new QComboBox();
     selectLangsBox->setToolTip(trUtf8("Recognition language"));
-    toolBar->insertWidget(actionRecognize, selectLangsBox);
+
    // connect(selectLangsBox->lineEdit(), SIGNAL(textChanged(QString)), this, SLOT(LangTextChanged(QString)));
 
     initSettings();
@@ -154,6 +159,14 @@ MainForm::MainForm(QWidget *parent): QMainWindow(parent)
         //fillLanguagesBoxTesseract();
         engineLabel->setText(trUtf8("Using Tesseract"));
     }
+
+    slAction = toolBar->insertWidget(actionRecognize, selectLangsBox);
+    langLabel = new QLabel();
+    statusBar()->addPermanentWidget(langLabel);
+    if (settings->getSelectedLanguages().count() == 1) {
+        slAction->setVisible(false);
+        langLabel->setText(trUtf8("Recognition Language") + ": " + settings->getFullLanguageName(settings->getLanguage()));
+    }
     fillLangBox();
     delTmpFiles();
     QXtUnixSignalCatcher::connectUnixSignal(SIGUSR2);
@@ -169,7 +182,6 @@ MainForm::MainForm(QWidget *parent): QMainWindow(parent)
    // textEdit->setContextMenuPolicy(Qt::ActionsContextMenu);
 
     this->sideBar->show();
-    //connect(sideBar, SIGNAL(fileSelected(const QString &)), this, SLOT(fileSelected(const QString &)));
 
     connect(actionRecognize_All_Pages, SIGNAL(triggered()), this, SLOT(recognizeAll()));
 
@@ -184,7 +196,6 @@ MainForm::MainForm(QWidget *parent): QMainWindow(parent)
     loadFromCommandLine();
     emit windowShown();
 
-    pdfx = NULL;
     if (findProgram("pdftoppm")) {
         pdfx = new PDF2PPT();
     } else
@@ -196,18 +207,7 @@ MainForm::MainForm(QWidget *parent): QMainWindow(parent)
         connect(pdfx, SIGNAL(addPage(QString)), this, SLOT(addPDFPage(QString)), Qt::QueuedConnection);
         connect (pdfx, SIGNAL(finished()), this, SLOT(finishedPDF()));
     }
-
-    pdfPD.setWindowTitle("YAGF");
-    pdfPD.setLabelText(trUtf8("Importing pages from the PDF document..."));
-    pdfPD.setCancelButtonText(trUtf8("Cancel"));
-    pdfPD.setMinimum(-1);
-    pdfPD.setMaximum(-1);
-    pdfPD.setWindowIcon(QIcon(":/yagf.png"));
-    if (pdfx)
-        connect(&pdfPD, SIGNAL(canceled()), pdfx, SLOT(cancel()));
-
-    menu_Settings->addAction("UI Language", this, SLOT(setUILanguage()));
-
+    setupPDFPD();
 }
 
 void MainForm::onShowWindow()
@@ -234,11 +234,35 @@ void MainForm::loadFromCommandLine()
     }
 }
 
-void MainForm::loadFiles(QStringList files)
+void MainForm::loadFiles(const QStringList &files)
 {
-    for (int i = 0; i < files.count(); i++)
-        if (QFile::exists(files.at(i)))
-            loadFile(files.at(i));
+    if (files.count() == 1) {
+        if (QFile::exists(files.at(0))) {
+            if (files.at(0).endsWith(".tiff", Qt::CaseInsensitive)||files.at(0).endsWith(".tif", Qt::CaseInsensitive))
+                loadTIFF(files.at(0));
+            else
+                loadFile(files.at(0));
+        }
+        return;
+    }
+    QProgressDialog pd(this);
+    pd.setWindowTitle("YAGF");
+    pd.setLabelText(trUtf8("Loading files..."));
+    pd.setRange(1, files.count());
+    pd.setValue(1);
+    pd.show();
+    for (int i = 0; i < files.count(); i++) {
+        if (QFile::exists(files.at(i))) {
+            if (files.at(i).endsWith(".tiff", Qt::CaseInsensitive)||files.at(i).endsWith(".tif", Qt::CaseInsensitive))
+                loadTIFF(files.at(i));
+            else
+                loadFile(files.at(i));
+        }
+        pd.setValue(i+1);
+        QApplication::processEvents();
+        if (pd.wasCanceled())
+            break;
+    }
 }
 
 void MainForm::LangTextChanged(const QString &text)
@@ -251,23 +275,26 @@ void MainForm::LangTextChanged(const QString &text)
 void MainForm::showConfigDlg()
 {
     ConfigDialog dialog(this);
-    SelectedEngine ose = settings->getSelectedEngine();
-    if (settings->getSelectedEngine() == UseCuneiform)
-        dialog.setSelectedEngine(0);
-    else
-        dialog.setSelectedEngine(1);
-    dialog.setTessDataPath(settings->getTessdataPath());
     if (dialog.exec()) {
-        settings->setSelectedEngine(dialog.selectedEngine() == 0 ? UseCuneiform : UseTesseract);
-        settings->setTessdataPath(dialog.tessdataPath());
-        if (settings->getSelectedEngine() != ose) {
+
+        //if (settings->getSelectedEngine() != ose) {
             QString oldLang = selectLangsBox->currentText();
             selectLangsBox->clear();
             if (settings->getSelectedEngine() == UseCuneiform) {
                 engineLabel->setText(trUtf8("Using Cuneiform"));
+                if (settings->selectedLanguagesAvailableTo("cuneiform").count() == 0) {
+                    QMessageBox::warning(this, trUtf8("Warning"), trUtf8("Cuneiform doesn't support any of selected recognition langualges.\nFalling back to tesseract. Please install tesseract."));
+                    settings->setSelectedEngine(UseTesseract);
+                    engineLabel->setText(trUtf8("Using Tesseract"));
+                }
             }
             if (settings->getSelectedEngine() == UseTesseract) {
                 engineLabel->setText(trUtf8("Using Tesseract"));
+                if (settings->selectedLanguagesAvailableTo("tesseract").count() == 0) {
+                    QMessageBox::warning(this, trUtf8("Warning"), trUtf8("Tesseract doesn't support any of selected recognition langualges.\nFalling back to cueniform. Please install cuneiform."));
+                    settings->setSelectedEngine(UseCuneiform);
+                    engineLabel->setText(trUtf8("Using Cuneiform"));
+                }
             }
             fillLangBox();
             int newIndex = selectLangsBox->findText(oldLang);
@@ -286,6 +313,20 @@ void MainForm::showConfigDlg()
                 }
             }
 
+        //} else         fillLangBox();
+
+
+        toolBar->setIconSize(settings->getIconSize());
+        if (selectLangsBox->count() > 1) {
+            slAction->setVisible(true);
+            langLabel->setText("");
+        }
+         else
+        {
+            if(settings->getSelectedLanguages().count() == 1) {
+                    slAction->setVisible(false);
+                    langLabel->setText(trUtf8("Recognition Language") + ": " + settings->getFullLanguageName(settings->getLanguage()));
+            }
         }
     }
 }
@@ -304,24 +345,15 @@ void MainForm::importPDF()
             return;
         }
         pdfx->setStartPage(dialog.getStartPage());
-        pdfx->setStopPage(dialog.getStopPage());
-        bool doit = true;
-        QString outputDir;
-        while (doit) {
-            outputDir = QFileDialog::getExistingDirectory(this, trUtf8("Select an existing directory for output or create some new one")); //, QString(""), QString(), (QString*) NULL, QFileDialog::ShowDirsOnly);
-            if (outputDir.isEmpty())
-                return;
-            QDir dir(outputDir);
-            if (dir.count() > 2)
-                QMessageBox::warning(this, trUtf8("Selecting Directory"), trUtf8("The selected directory is not empty"));
-            else doit = false;
-        }
-        pdfx->setOutputDir(outputDir);
-        QApplication::processEvents();
+        pdfx->setStopPage(dialog.getStopPage());        
+        pdfx->setOutputDir();
+        QApplication::processEvents();        
         pdfPD.setWindowFlags(Qt::Dialog|Qt::WindowStaysOnTopHint);
         pdfPD.show();
         pdfPD.setMinimum(0);
         pdfPD.setMaximum(100);
+        globalDeskew = settings->getAutoDeskew();
+        settings->setAutoDeskew(dialog.getDeskew());
         QApplication::processEvents();
         pdfx->exec();
     }
@@ -330,12 +362,23 @@ void MainForm::importPDF()
 void MainForm::addPDFPage(QString pageName)
 {
     pages->appendPage(pageName);
+    int fr = pdfx->filesRemaining(pageName);
+    if (fr > 0) {
+        int ft = pdfx->filesTotal();
+        if (ft != 0) {
+            int ratio = ((ft-fr)*100)/ft;
+            //if (ratio > pdfPD.value())
+                pdfPD.setValue(ratio);
+        }
+    } else
     pdfPD.setValue(pdfPD.value()+1);
 }
 
 void MainForm::finishedPDF()
 {
     pdfPD.hide();
+    //setupPDFPD();
+    settings->setAutoDeskew(globalDeskew);
 }
 
 void MainForm::loadImage()
@@ -347,15 +390,9 @@ void MainForm::loadImage()
         QStringList fileNames;
         fileNames = dialog.selectedFiles();
         settings->setLastDir(dialog.directory().path());
-        if (fileNames.count() > 0)
-         loadFile(fileNames.at(0), true);
-        if (!pages->pageValid())
-            return;
-        for (int i = 1; i < fileNames.count(); i++) {
-            loadFile(fileNames.at(i), false);
+        if (fileNames.count() > 0) {
+            loadFiles(fileNames);
         }
-//        if (fileNames.count() > 0)
-//            pages->makePageCurrent(0);
     }
 }
 
@@ -450,6 +487,7 @@ void MainForm::initSettings()
 
 void MainForm::newLanguageSelected(int index)
 {
+    if (index < 0) return;
     settings->setLanguage(selectLangsBox->itemData(index).toString());
     actionCheck_spelling->setEnabled(textEdit->hasDict(settings->getLanguage()));
     if (settings->getCheckSpelling()) {
@@ -497,15 +535,34 @@ void MainForm::loadFile(const QString &fn, bool loadIntoView)
     setCursor(oldCursor);
 }
 
+void MainForm::loadTIFF(const QString &fn, bool loadIntoView)
+{
+    TiffImporter ti(fn);
+    ti.exec();
+    QStringList files = ti.extractedFiles();
+    if (!files.count()) {
+        QMessageBox mb;
+        mb.setWindowTitle("YAGF");
+        mb.setIconPixmap(QPixmap(":/critical.png"));
+        mb.setText(trUtf8("Cannot open file %1. Make sure imagemagick and tifftopnm are installed.").arg(fn));
+        mb.addButton(QMessageBox::Close);
+        mb.exec();
+        return;
+    }
+    loadFiles(files);
+}
+
 void MainForm::delTmpFiles()
 {
 
     QDir dir(settings->workingDir());
     dir.setFilter(QDir::Files | QDir::NoSymLinks);
     for (uint i = 0; i < dir.count(); i++) {
-        if (dir[i].endsWith("jpg") || dir[i].endsWith("bmp") || dir[i].endsWith("png") || dir[i].endsWith("txt"))
+        if (dir[i].endsWith("jpg") || dir[i].endsWith("bmp") || dir[i].endsWith("png") || dir[i].endsWith("txt") || dir[i].endsWith("ygf"))
             dir.remove(dir[i]);
     }
+    if (pdfx)
+        pdfx->setOutputDir();
     delTmpDir();
 }
 
@@ -530,13 +587,25 @@ bool MainForm::useTesseract(const QString &inputFile)
     sl.append(settings->getLanguage());
     QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
     env.insert("TESSDATA_PREFIX", settings->getTessdataPath());
+    QDir dir(settings->getTessdataPath()+"tessdata/");
+    QStringList sl1;
+    sl1 << QString::fromUtf8("*%1.*").arg(settings->getLanguage());
+    if (dir.entryList(sl1, QDir::Files).count() == 0) {
+        QMessageBox mb(this);
+        mb.setIconPixmap(QPixmap(":/warning.png"));
+        mb.setWindowTitle("tesseract");
+        mb.setText(trUtf8("You have selected recognising %1 language using tesseract OCR. Currently the data for this language is not installed in your system. Please install the tesseract data files for \"%2\" from your system repository.").arg(settings->getFullLanguageName(settings->getLanguage())).arg(settings->getLanguage()));
+        mb.addButton(QMessageBox::Ok);
+        mb.exec();
+        return false;
+    }
     proc.setProcessEnvironment(env);
     proc.start("tesseract", sl);
     proc.waitForFinished(-1);
     if (proc.exitCode()) {
-        QByteArray stdout = proc.readAllStandardOutput();
-        QByteArray stderr = proc.readAllStandardError();
-        QString output = QString(stdout) + QString(stderr);
+        QByteArray stdoutBytes = proc.readAllStandardOutput();
+        QByteArray stderrBytes = proc.readAllStandardError();
+        QString output = QString(stdoutBytes) + QString(stderrBytes);
         QMessageBox::critical(this, trUtf8("Starting tesseract failed"), trUtf8("The system said: ") + (output != "" ? output : trUtf8("program not found")));
         return false;
     }
@@ -561,9 +630,9 @@ bool MainForm::useCuneiform(const QString &inputFile, const QString &outputFile)
     proc.start("cuneiform", sl);
     proc.waitForFinished(-1);
     if (proc.exitCode()) {
-        QByteArray stdout = proc.readAllStandardOutput();
-        QByteArray stderr = proc.readAllStandardError();
-        QString output = QString(stdout) + QString(stderr);
+        QByteArray stdoutBytes = proc.readAllStandardOutput();
+        QByteArray stderrBytes = proc.readAllStandardError();
+        QString output = QString(stdoutBytes) + QString(stderrBytes);
         QMessageBox::critical(this, trUtf8("Starting cuneiform failed"), trUtf8("The system said: ") + (output != "" ? output : trUtf8("program not found")));
         return false;
     }
@@ -625,7 +694,7 @@ void MainForm::showAboutDlg()
 {
     QPixmap icon;
     icon.load(":/yagf.png");
-    QMessageBox aboutBox(QMessageBox::NoIcon, trUtf8("About YAGF"), trUtf8("<p align=\"center\"><b>YAGF - Yet Another Graphical Front-end for cuneiform and tesseract OCR engines</b></p><p align=\"center\">Version %1</p> <p align=\"center\">Ⓒ 2009-2013 Andrei Borovsky</p> This is a free software distributed under GPL v3. Visit <a href=\"http://symmetrica.net/cuneiform-linux/yagf-en.html\">http://symmetrica.net/cuneiform-linux/yagf-en.html</a> for more details.").arg(version), QMessageBox::Ok);
+    QMessageBox aboutBox(QMessageBox::NoIcon, trUtf8("About YAGF"), trUtf8("<p align=\"center\"><b>YAGF - Yet Another Graphical Front-end for cuneiform and tesseract OCR engines</b></p><p align=\"center\">Version %1</p> <p align=\"center\">Ⓒ 2009-2014 Andrei Borovsky</p> This is a free software distributed under GPL v3. Visit <a href=\"http://symmetrica.net/cuneiform-linux/yagf-en.html\">http://symmetrica.net/cuneiform-linux/yagf-en.html</a> for more details.").arg(version), QMessageBox::Ok);
     aboutBox.setIconPixmap(icon);
     QList<QLabel *> labels = aboutBox.findChildren<QLabel *>();
     for (int i = 0; i < labels.count(); i++) {
@@ -662,7 +731,7 @@ void MainForm::delTmpDir()
     dir.setPath(settings->workingDir() + "output_files");
     dir.setFilter(QDir::Files | QDir::NoSymLinks);
     for (uint i = 0; i < dir.count(); i++) {
-        if (dir[i].endsWith("jpg") || dir[i].endsWith("bmp"))
+        if (dir[i].endsWith("jpg") || dir[i].endsWith("bmp") || dir[i].endsWith("ygf"))
             dir.remove(dir[i]);
     }
     dir.rmdir(settings->workingDir() + "output_files");
@@ -673,6 +742,7 @@ void MainForm::delTmpDir()
 void MainForm::clearTmpFiles()
 {
     QFile::remove(settings->workingDir() + "tmp*.bmp");
+    QFile::remove(settings->workingDir() + "tmp*.ygf");
     QFile f(settings->workingDir()+inputFile);
     f.remove();
     f.setFileName(settings->workingDir()+outputFile);
@@ -681,13 +751,18 @@ void MainForm::clearTmpFiles()
 
 void MainForm::fillLangBox()
 {
+    disconnect(selectLangsBox, SIGNAL(currentIndexChanged(int)), this, SLOT(newLanguageSelected(int)));
+    QStringList sl = Settings::instance()->getSelectedLanguages();
     settings->startLangPair();
     QString full;
     QString abbr;
     selectLangsBox->clear();
-    while(settings->getLangPair(full, abbr))
-        selectLangsBox->addItem(full, QVariant(abbr));
-
+    while(settings->getLangPair(full, abbr)) {
+        if (sl.contains(full)||(sl.count()== 0))
+            selectLangsBox->addItem(full, QVariant(abbr));
+    }
+    selectLangsBox->setCurrentIndex(-1);
+    connect(selectLangsBox, SIGNAL(currentIndexChanged(int)), this, SLOT(newLanguageSelected(int)));
 }
 
 void MainForm::preparePageForRecognition()
@@ -787,6 +862,21 @@ void MainForm::rightMouseClicked(int x, int y, bool inTheBlock)
     m_menu->show();
 }
 
+void MainForm::setupPDFPD()
+{
+    pdfPD.setWindowTitle("YAGF");
+    pdfPD.setLabelText(trUtf8("Importing pages from the PDF document..."));
+    pdfPD.setCancelButton(new QPushButton());
+    pdfPD.setCancelButtonText(trUtf8("Cancel"));
+    pdfPD.setMinimum(-1);
+    pdfPD.setMaximum(-1);
+    pdfPD.setWindowIcon(QIcon(":/yagf.png"));
+    if (pdfx) {
+        connect(&pdfPD, SIGNAL(canceled()), pdfx, SLOT(cancel()));
+        connect(&pdfPD, SIGNAL(canceled()), this, SLOT(cancelPDF()));
+    }
+}
+
 void MainForm::on_ActionDeleteBlock_activated()
 {
     QRect r = graphicsInput->getCurrentBlock();
@@ -804,7 +894,7 @@ bool MainForm::findEngine() {
         	        QMessageBox::warning(this, trUtf8("Warning"), trUtf8("No recognition engine found.\nPlease install either cuneiform or tesseract"));
         	        return false;
         	    }
-       		}
+            }
      	}
     	if (settings->getSelectedEngine() == UseTesseract) {
         	if (!findProgram("tesseract")) {
@@ -976,18 +1066,9 @@ void MainForm::selectTextArea()
     pages->blockAllText();
 }
 
-void MainForm::showAdvancedSettings()
-{
-    AdvancedConfigDialog dlg;
-    dlg.setCrop1(settings->getCropLoaded());
-    if (dlg.exec()) {
-        settings->setCropLoaded(dlg.doCrop1());
-    }
-}
-
 void MainForm::addSnippet(int index)
 {
-    sideBar->addItem((QListWidgetItem *) pages->snippet());
+    sideBar->addItem(pages->snippet());
 }
 
 void MainForm::preprocessPage()
@@ -1052,21 +1133,6 @@ void MainForm::selectBlocks()
     setCursor(oldCursor);
 }
 
-void MainForm::setSmallIcons()
-{
-    QSize s = toolBar->iconSize();
-    if (s.height() > 32) {
-         s.setHeight(32);
-         s.setWidth(32);
-    }
-    else {
-        s.setHeight(48);
-        s.setWidth(48);
-    }
-    toolBar->setIconSize(s);
-    settings->setIconSize(s);
-}
-
 void MainForm::selectHTMLformat()
 {
     if (actionSelect_HTML_format->isChecked())
@@ -1076,26 +1142,23 @@ void MainForm::selectHTMLformat()
 
 }
 
-void MainForm::setUILanguage()
+
+void MainForm::SelectRecognitionLanguages()
 {
-    ForceLocaleDialog fld(this);
-    if (settings->useNoLocale())
-        fld.setOption(ForceLocaleDialog::NoLocale);
-    else {
-        if (settings->useRussianLocale())
-            fld.setOption(ForceLocaleDialog::RussianLocale);
-        else {
-            fld.setOption(ForceLocaleDialog::DefaultLocale);
-        }
-    }
-    if (fld.exec() == QDialog::Accepted) {
-        settings->setNoLocale(false);
-        settings->setRussianLocale(false);
-        if (fld.getOption() == ForceLocaleDialog::NoLocale)
-            settings->setNoLocale(true);
-        else {
-            if (fld.getOption() == ForceLocaleDialog::RussianLocale)
-                settings->setRussianLocale(true);
-        }
-    }
+    LangSelectDialog lsd;
+    if (lsd.exec() == QDialog::Accepted)
+        fillLangBox();
+}
+
+void MainForm::cancelPDF()
+{
+    pdfx->removeRemaining();
+   //pdfPD.setLabelText(trUtf8("Opening already imported pages..."));
+    // pdfPD.setCancelButton(0);
+}
+
+void MainForm::selectLanguages()
+{
+    LangSelectDialog lsd(this); // ;)
+    lsd.exec();
 }
