@@ -1,6 +1,6 @@
 /*
     YAGF - cuneiform and tesseract OCR graphical front-end
-    Copyright (C) 2009-2013 Andrei Borovsky <anb@symmetrica.net>
+    Copyright (C) 2009-2012 Andrei Borovsky <anb@symmetrica.net>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,8 +40,9 @@ class QMenu;
 class PDFExtractor;
 class ccbuilder;
 class QLabel;
+class QAction;
 
-const QString version = "0.9.2.1";
+const QString version = "0.9.3.2";
 
 class PageCollection;
 class ScannerBase;
@@ -91,14 +92,17 @@ private slots:
     void deskewByBlock();
     void selectTextArea();
     void selectBlocks();
-    void setSmallIcons();
     void selectHTMLformat();
-    void loadFiles(QStringList files);
+    void loadFiles(const QStringList &files);
     void LangTextChanged(const QString &text);
+    void SelectRecognitionLanguages();
+    void cancelPDF();
+    void selectLanguages();
 private:
     virtual void closeEvent(QCloseEvent *event);
     void initSettings();
     void loadFile(const QString &fn, bool loadIntoView = true);
+    void loadTIFF(const QString &fn, bool loadIntoView = true);
     //void loadFileWithPixmap(const QString &fn, const QPixmap &pixmap);
     void delTmpFiles();
     void delTmpDir();
@@ -129,6 +133,9 @@ private:
     Settings * settings;
     PageCollection * pages;
     QLabel * engineLabel;
+    QLabel * langLabel;
+    QAction * slAction;
+    bool globalDeskew;
 private slots:
     bool findEngine();
     void readyRead(int sig);
@@ -136,11 +143,10 @@ private slots:
     void setUnresizingCusor();
     void loadPage();
     void rightMouseClicked(int x, int y, bool inTheBlock);
+    void setupPDFPD();
     void onShowWindow();
-    void showAdvancedSettings();
     void addSnippet(int index);
     void preprocessPage();
     void saveProject();
     void loadProject();
-    void setUILanguage();
  };
