@@ -33,11 +33,15 @@ public:
     bool setPage(int id, const QString &name, const QImage &image = QImage());
     QString getName();
     int pageID();
+    int imageHeight();
+    int imageWidth();
 signals:
 public slots:
 private:
     QString name;
     int pid;
-};
+    int ih;
+    int iw
+;};
 
 #endif // QSNIPPET_H
