@@ -1,6 +1,6 @@
 /*
     YAGF - cuneiform and tesseract OCR graphical front-ends
-    Copyright (C) 2009-2013 Andrei Borovsky <anb@symmetrica.net>
+    Copyright (C) 2009-2012 Andrei Borovsky <anb@symmetrica.net>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -104,19 +104,8 @@ void ScannerBase::setPreloadLibrary(const QString &s)
 
 QString ScannerFactory::findPreloadLibrary()
 {
-    QFileInfo lib;
-    lib.setFile("/usr/local/lib/yagf/libxspreload.so");
-    if (!lib.exists()) {
-            lib.setFile("/usr/lib/yagf/libxspreload.so");
-            if (!lib.exists()) {
-                lib.setFile("/usr/lib64/yagf/libxspreload.so");
-                if (!lib.exists())
-                    lib.setFile("/usr/local/lib64/yagf/libxspreload.so");
-            }
-    }
-    if (lib.exists())
-        return lib.filePath();
-    else return "";
+    QString path = QString(PRILIBRARY_PATH);
+    return  path + QString("libxspreload.so");
 }
 
 void ScannerFactory::findFEs()
