@@ -44,10 +44,15 @@ void Settings::readSettings(const QString &path)
     mPath = path;
     mPath = mPath.append("yagf.ini");
     settings = new QSettings(mPath, QSettings::IniFormat);
+    version = settings->value("program/version").toString();
+    if (version.isEmpty())
+        fr = true;
+    else
+        fr = false;
     lastDir = settings->value("mainwindow/lastDir").toString();
     lastOutputDir = settings->value("mainwindow/lastOutputDir").toString();
     QString defEngine;
-    if (findProgram("tesseract")&&(!findProgram("cuneiform")))
+    if (findProgram("tesseract"))
         defEngine = "tesseract";
     else
         defEngine = "cuneiform";
@@ -69,16 +74,32 @@ void Settings::readSettings(const QString &path)
     tessdataPath = settings->value("ocr/tessData", QVariant(tessdataPath)).toString();
     if (tessdataPath.isEmpty())
         findTessDataPath();
+    languages = settings->value("ocr/selectedLanguages", QStringList(language)).toStringList();
     cropLoaded =  settings->value("processing/crop1", QVariant(true)).toBool();
+    autoDeskew =  settings->value("processing/deskew", QVariant(true)).toBool();
+    preprocess = settings->value("processing/preprocess", QVariant(true)).toBool();
     size = settings->value("mainwindow/size", QSize(800, 600)).toSize();
-    iconSize = settings->value("mainwindow/iconSize", QSize(48, 48)).toSize();
+    iconSize = settings->value("mainwindow/iconSize", QSize(24, 24)).toSize();
     position = settings->value("mainwindow/pos", QPoint(0, 0)).toPoint();
     fullScreen = settings->value("mainwindow/fullScreen", QVariant(false)).toBool();
+    darkBackgroundThreshold = settings->value("tweaks/darkBackgroundThreshold", QVariant(198)).toInt();
+    foregroundBrightenFactor = settings->value("tweaks/foregroundBrightenFactor", QVariant(32)).toInt();
+    globalBrightenFactor = settings->value("tweaks/globalBrightenFactor", QVariant(32)).toInt();
+    globalDarkenFactor = settings->value("tweaks/globalDarkenFactor", QVariant(32)).toInt();
+    globalDarkenThreshold = settings->value("tweaks/globalDarkenThreshold", QVariant(190)).toInt();
+    uSeed = settings->value("tweaks/seed", QVariant(1)).toInt();
+    tiffPS = settings->value("tweaks/tiffPageSize", QVariant(4000)).toString();
+    tiffD = settings->value("tweaks/tiffDensity", QVariant(300)).toString();
+}
 
+bool Settings::firstRun()
+{
+    return fr;
 }
 
 void Settings::writeSettings()
 {
+    settings->setValue("program/version", QString::fromUtf8("0.9.3"));
     settings->setValue("mainwindow/size", size);
     settings->setValue("mainwindow/iconSize", iconSize);
     settings->setValue("mainwindow/pos", position);
@@ -90,6 +111,7 @@ void Settings::writeSettings()
     settings->setValue("mainwindow/nolocale", noLocale);
     settings->setValue("mainwindow/rulocale", RussianLocale);
     settings->setValue("ocr/language", language);
+    settings->setValue("ocr/selectedLanguages", languages);
 
     //settings->setValue("ocr/singleColumn", singleColumn);
     settings->setValue("ocr/outputFormat", outputFormat);
@@ -97,6 +119,16 @@ void Settings::writeSettings()
     settings->setValue("ocr/engine", engine);
     settings->setValue("ocr/tessData", tessdataPath);
     settings->setValue("processing/crop1", cropLoaded);
+    settings->setValue("processing/deskew", autoDeskew);
+    settings->setValue("processing/preprocess", preprocess);
+    settings->setValue("tweaks/darkBackgroundThreshold", darkBackgroundThreshold);
+    settings->setValue("tweaks/foregroundBrightenFactor", foregroundBrightenFactor);
+    settings->setValue("tweaks/globalBrightenFactor", globalBrightenFactor);
+    settings->setValue("tweaks/globalDarkenFactor", globalDarkenFactor);
+    settings->setValue("tweaks/globalDarkenThreshold", globalDarkenThreshold);
+    settings->setValue("tweaks/tiffPageSize", tiffPS);
+    settings->setValue("tweaks/tiffDensity", tiffD);
+    settings->setValue("tweaks/seed", uSeed);
     settings->sync();
 }
 
@@ -157,11 +189,61 @@ int Settings::getFontSize()
     return fontSize;
 }
 
+QString Settings::getFullLanguageName(const QString &abbr)
+{
+    QMap<QString, QString> * map;
+    if (selectedEngine == UseCuneiform)
+        map = &cuMap;
+    if (selectedEngine == UseTesseract)
+        map = &tesMap;
+    return map->key(abbr, "");
+}
+
+QString Settings::getFullLanguageName(const QString &abbr, const QString &engine)
+{
+    QMap<QString, QString> * map;
+    if (engine == "cuneiform")
+        map = &cuMap;
+    if (engine == "tesseract")
+        map = &tesMap;
+    return map->key(abbr, "");
+}
+
+QString Settings::getShortLanguageName(const QString &lang)
+{
+    QMap<QString, QString> * map;
+    if (selectedEngine == UseCuneiform)
+        map = &cuMap;
+    if (selectedEngine == UseTesseract)
+        map = &tesMap;
+    return map->value(lang, "");
+}
+
+QString Settings::getShortLanguageName(const QString &lang, const QString &engine)
+{
+    QMap<QString, QString> * map;
+    if (engine == "tesseract")
+        map = &tesMap;
+    if (engine == "cuneiform")
+        map = &cuMap;
+    return map->value(lang, "");
+}
+
+bool Settings::getAutoDeskew()
+{
+    return autoDeskew;
+}
+
 bool Settings::getCropLoaded()
 {
     return cropLoaded;
 }
 
+bool Settings::getPreprocessed()
+{
+    return preprocess;
+}
+
 void Settings::setLanguage(const QString &value)
 {
     language = value;
@@ -222,6 +304,133 @@ void Settings::setCropLoaded(const bool value)
     cropLoaded = value;
 }
 
+void Settings::setAutoDeskew(const bool value)
+{
+    autoDeskew = value;
+}
+
+void Settings::setPreprocessed(const bool value)
+{
+    preprocess = value;
+}
+
+QString Settings::uniqueSeed()
+{
+    return QString::number(uSeed++);
+}
+
+QString Settings::tiffPageSize()
+{
+    return tiffPS;
+}
+
+QString Settings::tiffDensity()
+{
+    return tiffD;
+}
+
+int Settings::getDarkBackgroundThreshold()
+{
+    return darkBackgroundThreshold;
+}
+
+int Settings::getForegroundBrightenFactor()
+{
+    return foregroundBrightenFactor;
+}
+
+int Settings::getGlobalBrightenFactor()
+{
+    return globalBrightenFactor;
+}
+
+int Settings::getGlobalDarkenFactor()
+{
+    return globalDarkenFactor;
+}
+
+int Settings::getGlobalDarkenThreshold()
+{
+    return globalDarkenThreshold;
+}
+
+QStringList Settings::fullLanguageNames()
+{
+    QStringList res = tesMap.keys();
+    res << QObject::trUtf8("Russian-English");
+    return res;
+}
+
+QStringList Settings::getSelectedLanguages()
+{
+    QStringList res;
+    foreach (QString s, languages) {
+        QString l = getFullLanguageName(s, "tesseract");
+        if (l!="")
+            res.append(l);
+        l = getFullLanguageName(s, "cuneiform");
+        if (l!="")
+             res.append(l);
+    }
+    res.removeDuplicates();
+    return res;
+}
+
+QStringList Settings::selectedLanguagesAvailableTo(const QString &engine)
+{
+    QStringList res;
+    if (engine == "cuneiform") {
+        foreach(QString s, languages) {
+            if (cuMap.values().contains(s))
+                res.append(cuMap.key(s, ""));
+        }
+    }
+    if (engine == "tesseract") {
+        foreach(QString s, languages) {
+            if (tesMap.values().contains(s))
+                res.append(tesMap.key(s, ""));
+        }
+    }
+    return res;
+}
+
+QStringList Settings::languagesAvailableTo(const QString &engine)
+{
+    if (engine == "cuneiform")
+        return cuMap.keys();
+    if (engine == "tesseract")
+        return tesMap.keys();
+    return QStringList();
+}
+
+QStringList Settings::installedTesseractLanguages()
+{
+    QString tessPath = tessdataPath + "/tessdata/";
+    QDir d(tessPath);
+    QStringList res;
+    QStringList sl = d.entryList(QStringList("*.traineddata"));
+    foreach (QString s, tesMap.values()) {
+        foreach(QString s1, sl) {
+            if (s1.startsWith(s))
+                res.append(tesMap.key(s, ""));
+        }
+    }
+    res.removeDuplicates();
+    return res;
+}
+
+void Settings::setSelectedLanguages(const QStringList &value)
+{
+    languages.clear();
+    foreach (QString s, value) {
+        QString l = getShortLanguageName(s, "tesseract");
+        if (l!="") languages.append(l);
+        l =getShortLanguageName(s, "cuneiform");
+        if (l!="") languages.append(l);
+    }
+    languages.removeDuplicates();
+}
+
 QString Settings::workingDir()
 {
     QString wDir = QDir::homePath();
@@ -235,8 +444,11 @@ QString Settings::workingDir()
         wDir += '/';
     wDir += "yagf/";
     QDir dir(wDir);
-    if (!dir.exists())
+    if (!dir.exists()) {
         dir.mkdir(wDir);
+        fr = true;
+    }
+    else fr= false;
     return wDir;
 }
 
@@ -245,18 +457,21 @@ void Settings::startLangPair()
     lpi = 0;
 }
 
-bool Settings::getLangPair(QString &full, QString &abbr)
+bool Settings::getLangPair(QString &full, QString &abbr, bool forceTesseract)
 {
     QMap<QString, QString> * map;
     if (selectedEngine == UseCuneiform)
         map = &cuMap;
     if (selectedEngine == UseTesseract)
         map = &tesMap;
-    full = map->keys().at(lpi);
-    abbr = map->value(full);
-    lpi++;
-    if (lpi < map->count())
+    if (forceTesseract)
+        map = &tesMap;
+    if (lpi < map->count()) {
+        full = map->keys().at(lpi);
+        abbr = map->value(full);
+        lpi++;
         return true;
+    }
     return false;
 }
 
@@ -294,21 +509,31 @@ void Settings::makeLanguageMaps()
     cuMap.insert(QObject::trUtf8("Swedish"), "swe");
     cuMap.insert(QObject::trUtf8("Ukrainian"), "ukr");
 
+    tesMap.insert(QObject::trUtf8("Albanian"), "sqi");
+    tesMap.insert(QObject::trUtf8("Ancient Greek"), "grc");
+    tesMap.insert(QObject::trUtf8("Azerbaijani"), "aze");
     tesMap.insert(QObject::trUtf8("Bulgarian"), "bul");
     tesMap.insert(QObject::trUtf8("Czech"), "ces");
+    tesMap.insert(QObject::trUtf8("Croatian"), "hrv");
     tesMap.insert(QObject::trUtf8("Danish"), "dan");
+    tesMap.insert(QObject::trUtf8("Danish Gothic"), "dan-frak");
     tesMap.insert(QObject::trUtf8("Dutch"), "nld");
     tesMap.insert(QObject::trUtf8("English"), "eng");
+    tesMap.insert(QObject::trUtf8("Estonian"), "est");
     tesMap.insert(QObject::trUtf8("Finnish"), "fin");
     tesMap.insert(QObject::trUtf8("French"), "fra");
     tesMap.insert(QObject::trUtf8("German"), "deu");
-    tesMap.insert(QObject::trUtf8("German Gothic"), "gerf");
+    tesMap.insert(QObject::trUtf8("German Gothic"), "deu-frak");
     tesMap.insert(QObject::trUtf8("Greek"), "ell");
     tesMap.insert(QObject::trUtf8("Hebrew"), "heb");
     tesMap.insert(QObject::trUtf8("Hungarian"), "hun");
+    tesMap.insert(QObject::trUtf8("Icelandic"), "isl");
     tesMap.insert(QObject::trUtf8("Italian"), "ita");
     tesMap.insert(QObject::trUtf8("Latvian"), "lav");
     tesMap.insert(QObject::trUtf8("Lithuanian"), "lit");
+    tesMap.insert(QObject::trUtf8("Macedonian"), "mkd");
+    tesMap.insert(QObject::trUtf8("Middle English"), "enm");
+    tesMap.insert(QObject::trUtf8("Middle French"), "frm");
     tesMap.insert(QObject::trUtf8("Norwegian"), "nor");
     tesMap.insert(QObject::trUtf8("Polish"), "pol");
     tesMap.insert(QObject::trUtf8("Portuguese"), "por");
@@ -316,10 +541,11 @@ void Settings::makeLanguageMaps()
     tesMap.insert(QObject::trUtf8("Russian"), "rus");
     tesMap.insert(QObject::trUtf8("Serbian"), "srp");
     tesMap.insert(QObject::trUtf8("Slovenian"), "slv");
-    tesMap.insert(QObject::trUtf8("Slovak"), "slk");
+    tesMap.insert(QObject::trUtf8("Slovakian"), "slk");
+    tesMap.insert(QObject::trUtf8("Slovakian Gothic"), "slk-frak");
     tesMap.insert(QObject::trUtf8("Spanish"), "spa");
     tesMap.insert(QObject::trUtf8("Swedish"), "swe");
-    tesMap.insert(QObject::trUtf8("Swedish Gothic"), "swef");
+    tesMap.insert(QObject::trUtf8("Swedish Gothic"), "swe-frak");
     tesMap.insert(QObject::trUtf8("Turkish"), "tur");
     tesMap.insert(QObject::trUtf8("Ukrainian"), "ukr");
 
@@ -446,6 +672,7 @@ QString Settings::selectDefaultLanguageName()
                 name = map->value("Turkish", "eng");
                 break;
             default:
+                name = "eng";
                 break;
         }
     if (name == "")
