@@ -19,6 +19,7 @@
 #include <QPoint>
 #include <QMap>
 #include <QLocale>
+#include <QStringList>
 
 
 enum SelectedEngine {
@@ -31,6 +32,7 @@ class Settings
 public:
   static Settings * instance();
   void readSettings(const QString &path);
+  bool firstRun();
   void writeSettings();
   QString getLanguage();
   bool useNoLocale();
@@ -48,7 +50,13 @@ public:
   QPoint getPosition();
   bool getFullScreen();
   int getFontSize();
+  QString getFullLanguageName(const QString &abbr);
+  QString getFullLanguageName(const QString &abbr, const QString &engine);
+  QString getShortLanguageName(const QString &lang);
+  QString getShortLanguageName(const QString &lang, const QString &engine);
+  bool getAutoDeskew();
   bool getCropLoaded();
+  bool getPreprocessed();
   void setLanguage(const QString &value);
   void setOutputFormat(const QString &value);
   void setLastDir(const QString &value);
@@ -62,9 +70,25 @@ public:
   void setFullScreen(const bool value);
   void setFontSize(const int &value);
   void setCropLoaded(const bool value);
+  void setAutoDeskew(const bool value);
+  void setPreprocessed(const bool value);
+  QString uniqueSeed();
+  QString tiffPageSize();
+  QString tiffDensity();
+  int getDarkBackgroundThreshold();
+  int getForegroundBrightenFactor();
+  int getGlobalBrightenFactor();
+  int getGlobalDarkenFactor();
+  int getGlobalDarkenThreshold();
+  QStringList fullLanguageNames();
+  QStringList getSelectedLanguages();
+  QStringList selectedLanguagesAvailableTo(const QString &engine);
+  QStringList languagesAvailableTo(const QString &engine);
+  QStringList installedTesseractLanguages();
+  void setSelectedLanguages(const QStringList &value);
   QString workingDir();
   void startLangPair();
-  bool getLangPair(QString &full, QString &abbr);
+  bool getLangPair(QString &full, QString &abbr, bool forceTesseract = false);
   void setProjectDir(const QString &dir);
   QString getProjectDir();
   void makeLanguageMaps();
@@ -80,6 +104,7 @@ private:
   QString lastDir;
   QString lastOutputDir;
   QString projectDir;
+  QString version;
   bool checkSpelling;
   QString tessdataPath;
   SelectedEngine selectedEngine;
@@ -89,14 +114,26 @@ private:
   bool fullScreen;
   int fontSize;
   bool cropLoaded;
+  bool preprocess;
+  bool fr;
   QMap<QString, QString> cuMap;
   QMap<QString, QString> tesMap;
   int lpi;
   bool noLocale;
   bool RussianLocale;
+  bool autoDeskew;
+  int darkBackgroundThreshold;
+  int globalBrightenFactor;
+  int foregroundBrightenFactor;
+  int globalDarkenFactor;
+  int globalDarkenThreshold;
+  int uSeed;
+  QStringList languages;
   QString mPath;
   QSettings * settings;
   static Settings * m_instance;
+  QString tiffPS;
+  QString tiffD;
 };
 
 #endif
