@@ -1,6 +1,6 @@
 /*
     YAGF - cuneiform and tesseract OCR graphical front-end
-    Copyright (C) 2009-2013 Andrei Borovsky <anb@symmetrica.net>
+    Copyright (C) 2009-2012 Andrei Borovsky <anb@symmetrica.net>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,11 +40,15 @@ public:
     void setLanguage(const QString &lang);
     bool spellCheck();  //Returns false only if the dictionary not found. Otherwise always true.
     void checkWord();
+    bool hasHyphen(QTextCursor *cursor);
+    bool hasLongHyphen(QTextCursor *cursor);
+    QString checkConcatenation(QTextCursor *cursor);
     void enumerateDicts();
     bool hasDict(const QString &shname);
     QStringList suggestions();
 private:
     void _checkWord(QTextCursor *cursor);
+    bool checkWordSpelling(const QString &word);
     QTextEdit *m_textEdit;
     QRegExp *m_regExp;
     QString m_lang1;
