@@ -1,6 +1,6 @@
 /*
     YAGF - cuneiform and tesseract OCR graphical front-end
-    Copyright (C) 2009-2013 Andrei Borovsky <anb@symmetrica.net>
+    Copyright (C) 2009-2012 Andrei Borovsky <anb@symmetrica.net>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -18,10 +18,8 @@
 */
 
 #include "tpagecollection.h"
+#include "core/imageprocessor.h"
 #include "qsnippet.h"
-#ifdef TIFF_IO
-#include "qxttiffiohandler.h"
-#endif
 #include "settings.h"
 #include <QApplication>
 #include <QFile>
@@ -47,45 +45,52 @@ PageCollection::~PageCollection()
 
 bool PageCollection::appendPage(const QString &fileName)
 {
-    #ifdef TIFF_IO
-    if (fileName.endsWith(".tif", Qt::CaseInsensitive) || fileName.endsWith(".tiff", Qt::CaseInsensitive)) {
-        QXtTiffIOHandler * toh = new QXtTiffIOHandler();
-        QFile f(fileName);
-        f.open(QIODevice::ReadOnly);
-        toh->setDevice(&f);
-        if (toh->canRead()) {
-            if (toh->imageCount() == 1) {
-                delete toh;
-                appendPage(fileName);
-                return true;
-            } else {
-                for (int i = 0; i < toh->imageCount(); i++) {
-                    QImage img;
-                    toh->jumpToImage(i);
-                    toh->read(&img);
-                    QString nfn = Settings::instance()->workingDir() + QString("tiff-page-%1.jpg").arg(i+1);
-                    img.save(nfn, "JPEG");
-                    appendPage(nfn);
-                    QApplication::processEvents();
-                }
-                delete toh;
-                return true;
-            }
-        } else return false;
-    } else 
-    #endif // TIFF_IO
-{
+
+
+        unloadAll();
         Page * p = new Page(++pid);
         connect(p,SIGNAL(refreshView()), this, SIGNAL(loadPage()));
-        if (p->loadFile(fileName)) {
+        if (p->loadFile(fileName, 1, false)) {
+
             pages.append(p);
             index = pages.count() - 1;
+            if (Settings::instance()->getAutoDeskew()) {
+                deskew();
+
+                //p->cropYGF();
+                //p->reSaveTmpPage();
+            }
             emit addSnippet(index);
+            connect(p, SIGNAL(textOut(QString)), SLOT(textOut(QString)));
             return true;
-        } else return false;
-    }
+        } else {
+            delete p;
+            pid--;
+            return false;
+        }
+
 }
 
+void PageCollection::newPage(const QString &fileName, qreal rotation, bool preprocessed, bool deskewed)
+{
+    if (cp())
+        cp()->unload();
+    Page * p = new Page(++pid);
+    connect(p,SIGNAL(refreshView()), this, SIGNAL(loadPage()));
+    p->setDeskewed(deskewed);
+    p->setPreprocessed(preprocessed);
+    if (p->loadFile(fileName, 1)) {
+        pages.append(p);
+        p->rotate(rotation);
+        index = pages.count() - 1;
+        emit addSnippet(index);
+        makePageCurrent(index);
+    }
+
+}
+
+
+
 int PageCollection::count()
 {
     return pages.count();
@@ -93,6 +98,8 @@ int PageCollection::count()
 
 bool PageCollection::makePageCurrent(int index)
 {
+    if (cp())
+        cp()->unload();
     this->index = index;
     return index < pages.count();
 }
@@ -109,6 +116,8 @@ void PageCollection::setBeforeFirst()
 
 bool PageCollection::makeNextPageCurrent()
 {
+    if (cp())
+        cp()->unload();
     index++;
     if (index < count())
         return true;
@@ -252,6 +261,13 @@ void PageCollection::reloadPage()
     emit loadPage();
 }
 
+void PageCollection::unloadAll()
+{
+    foreach(Page *p, pages) {
+        p->unload();
+    }
+}
+
 void PageCollection::makeLarger()
 {
     if (!cp()) return;
@@ -290,7 +306,8 @@ void PageCollection::rotate180()
 void PageCollection::deskew()
 {
     if (!cp()) return;
-    cp()->deskew();
+    if (cp()->textHorizontal())
+        cp()->deskew();
     emit loadPage();
 }
 
@@ -375,6 +392,11 @@ void PageCollection::pageRemoved(int id)
     emit loadPage();
 }
 
+void PageCollection::textOut(const QString &msg)
+{
+    emit messagePosted(msg);
+}
+
 PageCollection *PageCollection::instance()
 {
     if (!m_instance)
