@@ -1,6 +1,6 @@
 /*
     YAGF - cuneiform and tesseract OCR graphical front-end
-    Copyright (C) 2009-2013 Andrei Borovsky <anb@symmetrica.net>
+    Copyright (C) 2009-2012 Andrei Borovsky <anb@symmetrica.net>
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -34,6 +34,7 @@ public:
     static PageCollection * instance();
     static void clearCollection();
     bool appendPage(const QString &fileName);
+    void newPage(const QString &fileName, qreal rotation, bool preprocessed, bool deskewed);
     int count();
     bool makePageCurrent(int index);
     bool makePageCurrentByID(int id);
@@ -60,6 +61,7 @@ public:
     void setDeskewed(const bool value);
     void setPreprocessed(const bool value);
     void reloadPage();
+    void unloadAll();
 public slots:
     void makeLarger();
     void makeSmaller();
@@ -77,9 +79,11 @@ signals:
     void loadPage(); // The page is already current
     void addSnippet(int index);
     void cleared();
+    void messagePosted(const QString &msg);
 private slots:
     void pageSelected(int id);
     void pageRemoved(int id);
+    void textOut(const QString &msg);
 private:
     PageCollection(QObject *parent = 0);
     PageCollection(const PageCollection &);
