@@ -1,42 +1,126 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
 <TS version="2.0" language="ru_RU">
-<context>
-    <name>AdvancedConfigDialog</name>
-    <message>
-        <source>Advanced Settings</source>
-        <translation>Дополнительные настройки</translation>
-    </message>
-    <message>
-        <source>Crop Image When Loaded</source>
-        <translation>Обрезать изображение при загрузке</translation>
-    </message>
-</context>
 <context>
     <name>ConfigDialog</name>
-    <message>
-        <source>OCR Settings</source>
-        <translation>Настройки программ распознавания</translation>
-    </message>
     <message>
         <source>OCR Engine</source>
         <translation>Программа распознавания</translation>
     </message>
     <message>
-        <source>cuneiform</source>
-        <translation>cuneiform</translation>
+        <source>YAGF Settings</source>
+        <translation>Настройки YAGF</translation>
     </message>
     <message>
-        <source>tesseract</source>
-        <translation>tesseract</translation>
+        <source>OCR and Languages</source>
+        <translation>Распознавание</translation>
     </message>
     <message>
-        <source>Tesseract Setup</source>
-        <translation>Настройка tesseract</translation>
+        <source>Image Processing</source>
+        <translation>Обработка изображений</translation>
     </message>
     <message>
-        <source>Location of the  tessdata directory:</source>
-        <translation>Расположение директории tessdata:</translation>
+        <source>Program Appearance</source>
+        <translation>Внешний вид программы</translation>
+    </message>
+    <message>
+        <source>Cuneiform</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Tesseract</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Path to Tesseract Data Files</source>
+        <translation>Расположение данных Tesseract</translation>
+    </message>
+    <message>
+        <source>...</source>
+        <translation>...</translation>
+    </message>
+    <message>
+        <source>Recognize Languages</source>
+        <translation>Распознавать языки</translation>
+    </message>
+    <message>
+        <source>Use Single Language:</source>
+        <translation>Только один язык:</translation>
+    </message>
+    <message>
+        <source>Choose Among Several Languages </source>
+        <translation>Несколько языков</translation>
+    </message>
+    <message>
+        <source>Languages to Use...</source>
+        <translation>Языки...</translation>
+    </message>
+    <message>
+        <source>Enhance Image Quality</source>
+        <translation>Улучшить качество изображения</translation>
+    </message>
+    <message>
+        <source>Crop Image When Loaded</source>
+        <translation>Обрезать изображение при загрузке</translation>
+    </message>
+    <message>
+        <source>Deskew Loaded Images</source>
+        <translation>Автоматически корректировать наклон</translation>
+    </message>
+    <message>
+        <source>Preprocess Images When Loaded</source>
+        <translation>Корректировать изображения при загрузке</translation>
+    </message>
+    <message>
+        <source>Interface Language</source>
+        <translation>Язык интерфейса</translation>
+    </message>
+    <message>
+        <source>Select Language of the Interface:</source>
+        <translation>Выбрать язык интерфейса:</translation>
+    </message>
+    <message>
+        <source>Toolbar Icon Size</source>
+        <translation>Размер иконок</translation>
+    </message>
+    <message>
+        <source>Normal</source>
+        <translation>Обычный</translation>
+    </message>
+    <message>
+        <source>Large</source>
+        <translation>Крупный</translation>
+    </message>
+    <message>
+        <source>Tesseract Data Directory</source>
+        <translation>Расположение данных Tesseract</translation>
+    </message>
+</context>
+<context>
+    <name>LangSelectDialog</name>
+    <message>
+        <source>YAGF Languages Setup</source>
+        <translation>Выбор языков для распознавания</translation>
+    </message>
+    <message>
+        <source>Select the recognition languages </source>
+        <translation>Выбрать языки для распознавания</translation>
+    </message>
+    <message>
+        <source>Cuneiform</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Tesseract</source>
+        <translation></translation>
+    </message>
+    <message>
+        <source>Installed</source>
+        <translation>Установлен</translation>
+    </message>
+    <message>
+        <source>Not installed</source>
+        <translation>Не установлен</translation>
     </message>
 </context>
 <context>
@@ -55,7 +139,7 @@
     </message>
     <message>
         <source>There is an unsaved text in the editor window. Do you want to save it?</source>
-        <translation>В окне редактора несохраненный текст. Сохранить?</translation>
+        <translation>В окне редактора несохранённый текст. Сохранить?</translation>
     </message>
     <message>
         <source>Warning</source>
@@ -111,24 +195,12 @@
     </message>
     <message>
         <source>No compatible PDF converter software could be found. Please install either the pdftoppm utility or the GhostScript package (from this the gs command will be required).</source>
-        <translation>Не найдены подходящие конверторы PDF. Установите, пожалуйста, утилиту pdftoppm или пакет GhostScript (из которого требуется программа gs).</translation>
+        <translation>Не найдены подходящие конвертeры PDF. Установите, пожалуйста, утилиту pdftoppm или пакет GhostScript (из которого требуется программа gs).</translation>
     </message>
     <message>
         <source>PDF file name may not be empty</source>
         <translation>Необходимо указать имя файла PDF</translation>
     </message>
-    <message>
-        <source>Select an existing directory for output or create some new one</source>
-        <translation>Выберите существующую директорию для вывода или создайте новую</translation>
-    </message>
-    <message>
-        <source>Selecting Directory</source>
-        <translation>Выбор директории</translation>
-    </message>
-    <message>
-        <source>The selected directory is not empty</source>
-        <translation>Выбранная директория - не пустая</translation>
-    </message>
     <message>
         <source>Starting tesseract failed</source>
         <translation>Не удалось запустить tesseract</translation>
@@ -151,10 +223,6 @@ Please install either cuneiform or tesseract</source>
         <source>No PDF converter installed</source>
         <translation>Конвертер PDF не установлен</translation>
     </message>
-    <message utf8="true">
-        <source>&lt;p align=&quot;center&quot;&gt;&lt;b&gt;YAGF - Yet Another Graphical Front-end for cuneiform and tesseract OCR engines&lt;/b&gt;&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;Version %1&lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Ⓒ 2009-2012 Andrei Borovsky&lt;/p&gt; This is a free software distributed under GPL v3. Visit &lt;a href=&quot;http://symmetrica.net/cuneiform-linux/yagf-en.html&quot;&gt;http://symmetrica.net/cuneiform-linux/yagf-en.html&lt;/a&gt; for more details.</source>
-        <translation>&lt;p align=&quot;center&quot;&gt;&lt;b&gt;YAGF - Графическая оболочка для программ распознавания текста cuneiform и tesseract&lt;/b&gt;&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;Версия %1&lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Ⓒ 2009-2012 Андрей Боровский&lt;/p&gt; YAGF - открытое программное обеспечение, которое распространяется на условиях лицензии GPL v3. Вы найдете подробности на странице &lt;a href=&quot;http://symmetrica.net/cuneiform-linux/yagf-en.html&quot;&gt;http://symmetrica.net/cuneiform-linux/yagf-ru.html&lt;/a&gt;.</translation>
-    </message>
     <message>
         <source>Using Cuneiform</source>
         <translation>Используется Cuneiform</translation>
@@ -173,12 +241,12 @@ Please install either cuneiform or tesseract</source>
     </message>
     <message>
         <source>Failed to Load Image</source>
-        <translation>Невозможно загруить выбранное изобажение</translation>
+        <translation>Невозможно загрузить выбранное изображение</translation>
     </message>
     <message>
         <source>Failed to detect text areas on this page.
 The page possibly lacks contrast. Try to select blocks manually.</source>
-        <translation>Не удалось найти ткстовые области на странице. Возможно, изображение отсканировано со слишком низким контрастом. Попробуйт выделить блоки вручную.</translation>
+        <translation>Не удалось найти текстовые области на странице. Возможно, изображение было сканировано со слишком низким контрастом. Попробуйте выделить блоки вручную.</translation>
     </message>
     <message>
         <source>The selected directoy is not empty. Please select or create another one.</source>
@@ -192,6 +260,37 @@ The page possibly lacks contrast. Try to select blocks manually.</source>
         <source>Failed to load project.</source>
         <translation>Невозможно открыть проект.</translation>
     </message>
+    <message>
+        <source>Loading files...</source>
+        <translatorcomment>Загрузка файлов...</translatorcomment>
+        <translation></translation>
+    </message>
+    <message>
+        <source>You have selected recognising %1 language using tesseract OCR. Currently the data for this language is not installed in your system. Please install the tesseract data files for &quot;%2&quot; from your system repository.</source>
+        <translation>Вы выбрали %1 язык для распознавания, используя программу tesseract. Данные для распознавания этого языка в настоящее время не установлены. Пожалуйста установите языковой пакет %2 из репозитория вашей системы.</translation>
+    </message>
+    <message utf8="true">
+        <source>&lt;p align=&quot;center&quot;&gt;&lt;b&gt;YAGF - Yet Another Graphical Front-end for cuneiform and tesseract OCR engines&lt;/b&gt;&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;Version %1&lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Ⓒ 2009-2014 Andrei Borovsky&lt;/p&gt; This is a free software distributed under GPL v3. Visit &lt;a href=&quot;http://symmetrica.net/cuneiform-linux/yagf-en.html&quot;&gt;http://symmetrica.net/cuneiform-linux/yagf-en.html&lt;/a&gt; for more details.</source>
+        <translation>&lt;p align=&quot;center&quot;&gt;&lt;b&gt;YAGF — графическая оболочка для программ распознавания текста cuneiform и tesseract&lt;/b&gt;&lt;/p&gt;&lt;p align=&quot;center&quot;&gt;Версия %1&lt;/p&gt; &lt;p align=&quot;center&quot;&gt;Ⓒ 2009-2014 Андрей Боровский&lt;/p&gt; YAGF — открытое программное обеспечение, которое распространяется на условиях лицензии GPL v3. Вы найдёте подробности на странице &lt;a href=&quot;http://symmetrica.net/cuneiform-linux/yagf-en.html&quot;&gt;http://symmetrica.net/cuneiform-linux/yagf-ru.html&lt;/a&gt;.</translation>
+    </message>
+    <message>
+        <source>Recognition Language</source>
+        <translation>Язык распознавания</translation>
+    </message>
+    <message>
+        <source>Cannot open file %1. Make sure imagemagick and tifftopnm are installed.</source>
+        <translation>Невозможно открыть файл %1. Проверьте, установлен ли imagemagick.</translation>
+    </message>
+    <message>
+        <source>Cuneiform doesn&apos;t support any of selected recognition langualges.
+Falling back to tesseract. Please install tesseract.</source>
+        <translation>Cuneiform не поддерживает ни один из выбранных языков. Используйте Tesseract.</translation>
+    </message>
+    <message>
+        <source>Tesseract doesn&apos;t support any of selected recognition langualges.
+Falling back to cueniform. Please install cuneiform.</source>
+        <translation>Tesseract не поддерживает ни один из выбранных языков. Используйте Cuneiform.</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -253,7 +352,7 @@ The page possibly lacks contrast. Try to select blocks manually.</source>
     </message>
     <message>
         <source>About...</source>
-        <translation>О програме...</translation>
+        <translation>О программе...</translation>
     </message>
     <message>
         <source>Clear all blocks</source>
@@ -273,11 +372,11 @@ The page possibly lacks contrast. Try to select blocks manually.</source>
     </message>
     <message>
         <source>Clear numbers</source>
-        <translation type="unfinished"></translation>
+        <translation>Очистить нумерацию</translation>
     </message>
     <message>
         <source>Crear block numbering</source>
-        <translation type="unfinished"></translation>
+        <translation>Очистить нумерацию блоков</translation>
     </message>
     <message>
         <source>Check spelling</source>
@@ -335,10 +434,6 @@ The page possibly lacks contrast. Try to select blocks manually.</source>
         <source>&amp;Help</source>
         <translation>&amp;Справка</translation>
     </message>
-    <message>
-        <source>Copy To Clipboard</source>
-        <translation>Копировать текст в буфер обмена</translation>
-    </message>
     <message>
         <source>Copy recognized text to clipboard</source>
         <translation>Копировать текст в буфер обмена</translation>
@@ -353,23 +448,23 @@ The page possibly lacks contrast. Try to select blocks manually.</source>
     </message>
     <message>
         <source>Ctrl+N</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+N</translation>
     </message>
     <message>
         <source>Ctrl+S</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+S</translation>
     </message>
     <message>
         <source>Ctrl+O</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+O</translation>
     </message>
     <message>
         <source>Ctrl+R</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+R</translation>
     </message>
     <message>
         <source>Ctrl+Q</source>
-        <translation type="unfinished"></translation>
+        <translation>Ctrl+Q</translation>
     </message>
     <message>
         <source>Recognize &amp;All Pages</source>
@@ -381,15 +476,11 @@ The page possibly lacks contrast. Try to select blocks manually.</source>
     </message>
     <message>
         <source>Ctrl+A</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Settings</source>
-        <translation>&amp;Настройки</translation>
+        <translation>Ctrl+A</translation>
     </message>
     <message>
         <source>&lt;&lt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;&lt;</translation>
     </message>
     <message>
         <source>Hide/Show Toolbar</source>
@@ -403,14 +494,6 @@ The page possibly lacks contrast. Try to select blocks manually.</source>
         <source>Import pages from PDF documents</source>
         <translation>Импорт страниц из документа PDF</translation>
     </message>
-    <message>
-        <source>OCR Settings</source>
-        <translation>Настройки программ распознавания</translation>
-    </message>
-    <message>
-        <source>Set up the OCR parameters</source>
-        <translation>Установить параметры программ распознавания</translation>
-    </message>
     <message>
         <source>Paste Image</source>
         <translation>Вставить изображение</translation>
@@ -439,14 +522,6 @@ The page possibly lacks contrast. Try to select blocks manually.</source>
         <source>Correct the page skew </source>
         <translation>Исправить наклон страницы</translation>
     </message>
-    <message>
-        <source>Advanced Settings</source>
-        <translation>Дополнительные настройки</translation>
-    </message>
-    <message>
-        <source>The settings you should probably never change</source>
-        <translation>Настройки, которые вам, скорее всего, менять не нужно</translation>
-    </message>
     <message>
         <source>select multiple blocks</source>
         <translation>Разделить текст на блоки</translation>
@@ -457,7 +532,7 @@ The page possibly lacks contrast. Try to select blocks manually.</source>
     </message>
     <message>
         <source>Toggle Large/Small Icons</source>
-        <translation>Большие/маленькие иконки</translation>
+        <translation>Большие/маленькие значки</translation>
     </message>
     <message>
         <source>toolBar_2</source>
@@ -467,10 +542,6 @@ The page possibly lacks contrast. Try to select blocks manually.</source>
         <source>Select Recognition Language</source>
         <translation>Выбор языка распознавания</translation>
     </message>
-    <message>
-        <source>Prepare Page</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Save Project...</source>
         <translation>Сохранить проект...</translation>
@@ -480,8 +551,36 @@ The page possibly lacks contrast. Try to select blocks manually.</source>
         <translation>Загрузить проект...</translation>
     </message>
     <message>
-        <source>Prepare the page for recognition</source>
-        <translation type="unfinished">Подготовить страницу для распознавания</translation>
+        <source>toolBar_3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Select Recognition Languages...</source>
+        <translation>Выбрать языки для распознавания...</translation>
+    </message>
+    <message>
+        <source>Select Recognition Languages</source>
+        <translation>Выбрать языки для распознавания</translation>
+    </message>
+    <message>
+        <source>&amp;Edit</source>
+        <translation>&amp;Правка</translation>
+    </message>
+    <message>
+        <source>Copy Text to Clipboard</source>
+        <translation>Скопировать текст в буфер обмена</translation>
+    </message>
+    <message>
+        <source>Settings</source>
+        <translation>Настройки</translation>
+    </message>
+    <message>
+        <source>Select All Text</source>
+        <translation>Выделить весь текст</translation>
+    </message>
+    <message>
+        <source>Select all the recognized text</source>
+        <translation>Выделить весь распознанный текст</translation>
     </message>
 </context>
 <context>
@@ -514,6 +613,10 @@ The page possibly lacks contrast. Try to select blocks manually.</source>
         <source>Entire Document</source>
         <translation>Весь документ</translation>
     </message>
+    <message>
+        <source>Don&apos;t Deskew Pages</source>
+        <translation>Отключить исправление наклона страниц</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -543,7 +646,7 @@ Try to install an appropriate aspell dictionary.</source>
     </message>
     <message>
         <source>Select Project Directory</source>
-        <translation>Выбор директории проекта</translation>
+        <translation>Выбор каталога проекта</translation>
     </message>
     <message>
         <source>Bulgarian</source>
@@ -647,11 +750,7 @@ Try to install an appropriate aspell dictionary.</source>
     </message>
     <message>
         <source>Norwegian</source>
-        <translation>Норевежский</translation>
-    </message>
-    <message>
-        <source>Slovak</source>
-        <translation>Словацкий</translation>
+        <translation>Норвежский</translation>
     </message>
     <message>
         <source>Swedish Gothic</source>
@@ -661,6 +760,54 @@ Try to install an appropriate aspell dictionary.</source>
         <source>Turkish</source>
         <translation>Турецкий</translation>
     </message>
+    <message>
+        <source>Albanian</source>
+        <translation>Албанский</translation>
+    </message>
+    <message>
+        <source>Ancient Greek</source>
+        <translation>Древнегреческий</translation>
+    </message>
+    <message>
+        <source>Azerbaijani</source>
+        <translation>Азербайджанский</translation>
+    </message>
+    <message>
+        <source>Croatian</source>
+        <translation>Хорватский</translation>
+    </message>
+    <message>
+        <source>Danish Gothic</source>
+        <translation>Датский готический</translation>
+    </message>
+    <message>
+        <source>Estonian</source>
+        <translation>Эстонский</translation>
+    </message>
+    <message>
+        <source>Icelandic</source>
+        <translation>Исландский</translation>
+    </message>
+    <message>
+        <source>Macedonian</source>
+        <translation>Македонский</translation>
+    </message>
+    <message>
+        <source>Middle English</source>
+        <translation>Старо-английский</translation>
+    </message>
+    <message>
+        <source>Middle French</source>
+        <translation>Старо-французский</translation>
+    </message>
+    <message>
+        <source>Slovakian</source>
+        <translation>Словацкий</translation>
+    </message>
+    <message>
+        <source>Slovakian Gothic</source>
+        <translation>Словацкий готический</translation>
+    </message>
 </context>
 <context>
     <name>SideBar</name>
